==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AssigningScatterMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningScatterStyleEventArgsBaseDescriptionMetadata } from "./AssigningScatterStyleEventArgsBaseDescriptionMetadata";
import { AssigningScatterMarkerStyleEventArgsDescription } from "./AssigningScatterMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningScatterMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningScatterMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningScatterMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningScatterMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningScatterMarkerStyleEventArgsDescriptionMetadata.c(AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.g(AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningScatterMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningScatterStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningScatterMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningScatterMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.u("AssigningScatterMarkerStyleEventArgs", function () { return new AssigningScatterMarkerStyleEventArgsDescription(); });
        a.t("AssigningScatterMarkerStyleEventArgs", AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningScatterMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningScatterMarkerStyleEventArgsDescriptionMetadata, 'AssigningScatterMarkerStyleEventArgsDescriptionMetadata');
    AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningScatterMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningScatterMarkerStyleEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AssigningScatterMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningScatterStyleEventArgsBaseDescriptionMetadata } from "./AssigningScatterStyleEventArgsBaseDescriptionMetadata";
import { AssigningScatterMarkerStyleEventArgsDescription } from "./AssigningScatterMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningScatterMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningScatterMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningScatterMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningScatterMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningScatterMarkerStyleEventArgsDescriptionMetadata.c(AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.j(AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningScatterMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningScatterStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningScatterMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningScatterMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.aa("AssigningScatterMarkerStyleEventArgs", function () { return new AssigningScatterMarkerStyleEventArgsDescription(); });
        a.z("AssigningScatterMarkerStyleEventArgs", AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningScatterMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningScatterMarkerStyleEventArgsDescriptionMetadata, 'AssigningScatterMarkerStyleEventArgsDescriptionMetadata');
    AssigningScatterMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningScatterMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningScatterMarkerStyleEventArgsDescriptionMetadata };
